==> aliyun-python-sdk-cdn-3.0.5.tar.gz: aliyun-python-sdk-cdn-3.0.5/aliyunsdkcdn/request/v20180510/SetRefererConfigRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class SetRefererConfigRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'SetRefererConfig')

	def get_ReferList(self):
		return self.get_query_params().get('ReferList')

	def set_ReferList(self,ReferList):
		self.add_query_param('ReferList',ReferList)

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_DomainName(self):
		return self.get_query_params().get('DomainName')

	def set_DomainName(self,DomainName):
		self.add_query_param('DomainName',DomainName)

	def get_ReferType(self):
		return self.get_query_params().get('ReferType')

	def set_ReferType(self,ReferType):
		self.add_query_param('ReferType',ReferType)

	def get_DisableAst(self):
		return self.get_query_params().get('DisableAst')

	def set_DisableAst(self,DisableAst):
		self.add_query_param('DisableAst',DisableAst)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_AllowEmpty(self):
		return self.get_query_params().get('AllowEmpty')

	def set_AllowEmpty(self,AllowEmpty):
		self.add_query_param('AllowEmpty',AllowEmpty)

==> aliyun-python-sdk-cdn-3.6.1.tar.gz: aliyun-python-sdk-cdn-3.6.1/aliyunsdkcdn/request/v20180510/SetRefererConfigRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcdn.endpoint import endpoint_data

class SetRefererConfigRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'SetRefererConfig')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ReferList(self):
		return self.get_query_params().get('ReferList')

	def set_ReferList(self,ReferList):
		self.add_query_param('ReferList',ReferList)

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_ReferType(self):
		return self.get_query_params().get('ReferType')

	def set_ReferType(self,ReferType):
		self.add_query_param('ReferType',ReferType)

	def get_DisableAst(self):
		return self.get_query_params().get('DisableAst')

	def set_DisableAst(self,DisableAst):
		self.add_query_param('DisableAst',DisableAst)

	def get_DomainName(self):
		return self.get_query_params().get('DomainName')

	def set_DomainName(self,DomainName):
		self.add_query_param('DomainName',DomainName)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_AllowEmpty(self):
		return self.get_query_params().get('AllowEmpty')

	def set_AllowEmpty(self,AllowEmpty):
		self.add_query_param('AllowEmpty',AllowEmpty)
